==> ServiceDesk-0.5.tar.gz: ServiceDesk/action.save_admin_mailsettings.php <==
<?php
# ServiceDesk (Service desk to support incidents and requests). A module for CMS - CMS Made Simple
# Copyright (c) 2008 by Duketown
#
# This function allows the administrator to update the preferences
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/servicedesk
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

$gCms = cmsms(); if( !is_object($gCms) ) exit;

if( !$this->CheckPermission( 'Modify Templates' ) )
{
  return;
}

// Normal save function
$this->SetPreference('sendmailincident', $params['sendmailincident']);
$this->SetPreference('receivedincidentmailsubject',$params['receivedincidentmailsubject']);
$this->SetTemplate('receiveincidentmailtemplate',$params['receiveincidentmailtemplate']);
$this->SetPreference('sendmailincident2admin', $params['sendmailincident2admin']);
$this->SetPreference('newincidentmailsubject2admin',$params['newincidentmailsubject2admin']);
$this->SetTemplate('newincidentmail2admintemplate',$params['newincidentmail2admintemplate']);

$params = array('tab_message'=> 'mailsettingsupdated', 'active_tab' => 'mailsettings');
$this->Redirect($id, 'defaultadmin', '', $params);
?>

==> ServiceDesk-0.7.tar.gz: ServiceDesk/action.save_admin_mailsettings.php <==
<?php
# ServiceDesk (Service desk to support incidents and requests). A module for CMS - CMS Made Simple
# Copyright (c) 2008 by Duketown
#
# This function allows the administrator to update the preferences
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/servicedesk
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

$gCms = cmsms(); if( !is_object($gCms) ) exit;

if( !$this->CheckPermission( 'Modify Templates' ) )
{
  return;
}

// Normal save function
if (isset($params['sendmailincident'])) {
	$this->SetPreference('sendmailincident', 1);
}
else {
	$this->SetPreference('sendmailincident', 0);
}

$this->SetPreference('receivedincidentmailsubject',$params['receivedincidentmailsubject']);
$this->SetTemplate('receiveincidentmailtemplate',$params['receiveincidentmailtemplate']);
if (isset($params['sendmailincident2admin'])) {
	$this->SetPreference('sendmailincident2admin', 1);
}
else {
	$this->SetPreference('sendmailincident2admin', 0);
}
$this->SetPreference('newincidentmailsubject2admin',$params['newincidentmailsubject2admin']);
$this->SetTemplate('newincidentmail2admintemplate',$params['newincidentmail2admintemplate']);

$params = array('tab_message'=> 'mailsettingsupdated', 'active_tab' => 'mailsettings');
$this->Redirect($id, 'defaultadmin', '', $params);
?>
